/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, Input, OnInit } from "@angular/core";
import { CapabilityRequest } from "../../../../model/capability-request";
import * as dayjs from 'dayjs';
import * as relativeTime from 'dayjs/plugin/relativeTime';
import * as localizedFormat from 'dayjs/plugin/localizedFormat';
@Component({
  selector: "app-request-header",
  templateUrl: "./request-header.component.html",
  styleUrls: ["./request-header.component.scss"],
})
export class RequestHeaderComponent implements OnInit {
  @Input() capabilityRequest: CapabilityRequest;
  createdAt;
  updatedAt;

  constructor() {}

  ngOnInit(): void {
    this.createdAt = this.formatDate(this.capabilityRequest.created_at)
    this.updatedAt = this.formatDate(this.capabilityRequest.updated_at)
  }

  private formatDate(date): string {
    dayjs.extend(relativeTime)
    dayjs.extend(localizedFormat)

    var dateFromNow = dayjs(date).fromNow()
    var afterOneWeekDisplay = dateFromNow + " on " + dayjs(date).format('llll');
    return this.isOlderThanOneWeek(date) ? afterOneWeekDisplay : dateFromNow;
  }

  private isOlderThanOneWeek(date): boolean {
    const now = dayjs();
    date = dayjs(date)
    return now.diff(date, "week") ? true : false
  }
}
