"""correcting restore imaging

Revision ID: c857908b6acb
Revises: 7b284596590c
Create Date: 2021-07-21 09:35:52.735903

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "c857908b6acb"
down_revision = "7b284596590c"
branch_labels = None
depends_on = None

condor = """executable = std_restore_imaging.sh
arguments = {{product_locator}} {{cal_locator}} {{request_id}} metadata.json PPR.xml

output = restore-img.out
error = restore-img.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products, delivery.json

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""

ppr = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/{{projectCode}}</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents/>
            <ProcessingProcedure>
                <ProcedureTitle>Workspaces Restore Imaging</ProcedureTitle>
                <ProcessingCommand>
                    <Command>hifv_restoredata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_statwt</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">breakpoint</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_mstransform</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_checkproductsize</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">maximsize</Keyword>
                            <Value xmlns="">16384</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">specmode</Keyword>
                            <Value xmlns="">cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">hm_masking</Keyword>
                            <Value xmlns="">none</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">hm_cyclefactor</Keyword>
                            <Value xmlns="">3.0</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_exportdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">imaging_products_only</Keyword>
                            <Value xmlns="">True</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>
    </ProcessingRequests>
</ns2:SciPipeRequest>

"""

metadata = """{
  "fileSetIds": ["{{sdmId}}", "{{calSdmId}}"],
  "workflowName": "std_restore_imaging",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "calProductLocator": "{{cal_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "telescope": "{{telescope}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}

"""


old_condor = """executable = std_restore_imaging.sh
arguments = {{product_locator}} {{cal_product_locator}} {{request_id}} metadata.json PPR.xml

output = restore.out
error = restore.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products, delivery.json

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""

old_ppr = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/null</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents>
                <Intents>
                    <Keyword>VLA_INTERFEROMETRY_STANDARD_OBSERVING_MODE</Keyword>
                    <Value>Undefined</Value>
                </Intents>
            </ProcessingIntents>
            <ProcessingProcedure>
                <ProcedureTitle>Workspaces Restore Imaging</ProcedureTitle>
                <ProcessingCommand>
                    <Command>hifv_restoredata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_statwt</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">breakpoint</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_mstransform</Command>
                    <ParameterSet>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_checkproductsize</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">maximsize</Keyword>
                            <Value xmlns="">16384</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">specmode</Keyword>
                            <Value xmlns="">cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">hm_masking</Keyword>
                            <Value xmlns="">none</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword xmlns="">hm_cyclefactor</Keyword>
                            <Value xmlns="">3.0</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command xmlns="">hifv_exportdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword xmlns="">imaging_products_only</Keyword>
                            <Value xmlns="">True</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>0
    </ProcessingRequests>
    <ResultsProcessing>
        <ArchiveResults>false</ArchiveResults>
        <CleanUpDisk>false</CleanUpDisk>
        <UpdateProjectLifeCycle>false</UpdateProjectLifeCycle>
        <NotifyOperatorWhenDone>false</NotifyOperatorWhenDone>
        <SDMall>false</SDMall>
        <SDMonly>false</SDMonly>
        <PipelineOperatorAddress>Unknown</PipelineOperatorAddress>
    </ResultsProcessing>
</ns2:SciPipeRequest>

"""

old_metadata = """{
  "fileSetIds": ["{{sdmId}}", "{{calSdmId}}"]
  "workflowName": "std_restore_imaging",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "calProductLocator": "{{cal_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{condor}' WHERE filename='std_restore_imaging.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{ppr}' WHERE filename='PPR.xml' AND workflow_name='std_restore_imaging'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{metadata}' WHERE filename='metadata.json' AND workflow_name='std_restore_imaging'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_condor}' WHERE filename='std_restore_imaging.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_ppr}' WHERE filename='PPR.xml' AND workflow_name='std_restore_imaging'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_metadata}' WHERE filename='metadata.json' AND workflow_name='std_restore_imaging'
        """
    )
